from pathlib import Path
import numpy as np
import cv2


def imread(path: Path | str) -> np.ndarray:
    img = cv2.imread(str(path))
    assert img is not None, f'Cannot read from {path}'
    return img[:, :, ::-1].copy()



import typing as tp


def flatten_list(l: tp.Any, times: int = -1):
    # Check exit contditions
    if times == 0:
        return l
    if not isinstance(l, list):
        if times >= 0:
            raise ValueError(f'{type(l)} is not list')
        else:
            return l

    # Flatten recursively
    new_l = []
    for sub_l in l:
        for item in sub_l:
            new_l.append(flatten_list(item, times - 1))
    return new_l
